@@ -34,7 +34,7 @@ LogMap = namedtuple("LogMap", "aux stderr stdout")
 
 class Report:
     DEFAULT_MAJOR = "NO_STACK"
-    DEFAULT_MINOR = "0"
+    DEFAULT_MINOR = "NO_STACK"
     HANG_STACK_HEIGHT = 10
     MAX_LOG_SIZE = 1_048_576  # 1MB
 
@@ -70,6 +70,7 @@ class Report:
         for log_file in (x for x in self._logs if x is not None):
             stack = Stack.from_text(log_file.read_text("utf-8", errors="ignore"))
             if stack.frames:
+                assert stack.minor is not None
                 # limit the hash calculations to the first n frames if a hang
                 # was detected to attempt to help local bucketing
                 stack.height_limit = self.HANG_STACK_HEIGHT if is_hang else None
@@ -172,7 +173,7 @@ class Report:
         if self._signature is None:
             collector = Collector()
             if collector.sigCacheDir and Path(collector.sigCacheDir).is_dir():
-                with InterProcessLock(str(Path(grz_tmp()) / "fm_sigcache.lock")):
+                with InterProcessLock(str(grz_tmp() / "fm_sigcache.lock")):
                     cache_sig, _ = collector.search(self.crash_info)
                     if cache_sig:
                         LOG.debug("signature loaded from cache file %r", cache_sig)
@@ -307,7 +308,8 @@ class Report:
 
     @staticmethod
     def _find_valgrind(logs):
-        """Search through list of log files for a Valgrind worker log.
+        """Search through list of log files for a Valgrind log.
+        Empty files are ignored.
 
         Args:
             logs (list(Path)): List of log files to search.
@@ -315,8 +317,8 @@ class Report:
         Returns:
             Path: Log file if a match is found otherwise None.
         """
-        for log_file in (x for x in logs if "valgrind" in x.name):
-            if log_file.stat().st_size:
+        for log_file in logs:
+            if "valgrind" in log_file.name and log_file.stat().st_size:
                 return log_file
         return None
 
@@ -375,7 +377,7 @@ class Report:
         """
         files = (x for x in path.iterdir() if x.is_file())
         # order by date hopefully the oldest log is the cause of the issue
-        to_scan = list(sorted(files, key=lambda x: x.stat().st_mtime))
+        to_scan = sorted(files, key=lambda x: x.stat().st_mtime)
         if not to_scan:
             LOG.warning("No files found in %r", path)
             return None
