@@ -1,4 +1,3 @@
-# coding=utf-8
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
@@ -11,10 +10,10 @@ from unittest.mock import Mock
 
 from pytest import mark, raises
 
+from .status import Status
 from .status_reporter import (
     ReductionStatus,
     ReductionStatusReporter,
-    Status,
     StatusReporter,
     TracebackReport,
     main,
@@ -23,6 +22,12 @@ from .status_reporter import (
 GBYTES = 1_073_741_824
 
 
+pytestmark = mark.usefixtures(
+    "tmp_path_status_db_fuzz",
+    "tmp_path_status_db_reduce",
+)
+
+
 def _fake_sys_info():
     return [
         ("CPU & Load", "64 @ 93% (85.25, 76.21, 51.06)"),
@@ -43,20 +48,18 @@ def test_reduce_status_reporter_01():
 def test_reduce_status_reporter_02(mocker, tmp_path):
     """test ReductionStatusReporter.load()"""
     # missing reports path
-    st_rpt = ReductionStatusReporter.load(str(tmp_path / "status.db"))
+    st_rpt = ReductionStatusReporter.load(tmp_path / "status.db")
     assert not st_rpt.reports
 
     # empty reports and tb paths
-    st_rpt = ReductionStatusReporter.load(
-        str(tmp_path / "status.db"), tb_path=str(tmp_path)
-    )
+    st_rpt = ReductionStatusReporter.load(tmp_path / "status.db", tb_path=tmp_path)
     assert not st_rpt.reports
     assert isinstance(st_rpt.tracebacks, list)
     assert not st_rpt.tracebacks
 
     # multiple reports
     size_cb = mocker.Mock(side_effect=count(start=1000, step=-100))
-    db_file = str(tmp_path / "status.db")
+    db_file = tmp_path / "status.db"
     ReductionStatus.start(
         db_file=db_file,
         testcase_size_cb=size_cb,
@@ -76,7 +79,7 @@ def test_reduce_status_reporter_03(mocker, tmp_path):
     mocker.patch("grizzly.common.status.getpid", side_effect=(1, 2))
     mocker.patch("grizzly.common.status.time", side_effect=count(start=1.0, step=1.0))
     size_cb = mocker.Mock(side_effect=count(start=1000, step=-100))
-    db_file = str(tmp_path / "status.db")
+    db_file = tmp_path / "status.db"
     # single report
     status = ReductionStatus.start(
         db_file=db_file,
@@ -118,7 +121,7 @@ def test_reduce_status_reporter_03(mocker, tmp_path):
 def test_reduce_status_reporter_04(mocker, tmp_path):
     """test ReductionStatusReporter.specific()"""
     mocker.patch("grizzly.common.status.getpid", side_effect=(1, 2))
-    db_file = str(tmp_path / "status.db")
+    db_file = tmp_path / "status.db"
     # single report
     status = ReductionStatus.start(
         db_file=db_file,
@@ -156,7 +159,7 @@ def test_reduce_status_reporter_04(mocker, tmp_path):
 
 def test_reduce_status_reporter_05(tmp_path):
     """test ReductionStatusReporter.load() with traceback"""
-    db_file = str(tmp_path / "status.db")
+    db_file = tmp_path / "status.db"
     status = ReductionStatus.start(
         db_file=db_file,
         testcase_size_cb=lambda: 47,
@@ -171,21 +174,21 @@ def test_reduce_status_reporter_05(tmp_path):
         test_fp.write(b"Traceback (most recent call last):\n")
         test_fp.write(b"  blah\n")
         test_fp.write(b"IndexError: list index out of range\n")
-    rptr = StatusReporter.load(db_file, tb_path=str(tmp_path))
+    rptr = StatusReporter.load(db_file, tb_path=tmp_path)
     assert len(rptr.tracebacks) == 1
     # create second screenlog
     with (tmp_path / "screenlog.1234").open("wb") as test_fp:
         test_fp.write(b"Traceback (most recent call last):\n")
         test_fp.write(b"  blah\n")
         test_fp.write(b"foo.bar.error: blah\n")
-    rptr = StatusReporter.load(db_file, tb_path=str(tmp_path))
+    rptr = StatusReporter.load(db_file, tb_path=tmp_path)
     assert len(rptr.tracebacks) == 2
     # create third screenlog
     with (tmp_path / "screenlog.3").open("wb") as test_fp:
         test_fp.write(b"Traceback (most recent call last):\n")
         test_fp.write(b"  blah\n")
         test_fp.write(b"KeyboardInterrupt\n")
-    rptr = ReductionStatusReporter.load(db_file, tb_path=str(tmp_path))
+    rptr = ReductionStatusReporter.load(db_file, tb_path=tmp_path)
     assert len(rptr.tracebacks) == 2
     merged_log = rptr.summary()
     assert len(merged_log.splitlines()) == 13
@@ -198,7 +201,7 @@ def test_reduce_status_reporter_05(tmp_path):
 
 def test_status_reporter_01():
     """test basic StatusReporter"""
-    st_rpt = StatusReporter(list())
+    st_rpt = StatusReporter([])
     assert not st_rpt.has_results
     st_rpt._sys_info = _fake_sys_info
     assert "No status reports available" in st_rpt.specific()
@@ -208,10 +211,10 @@ def test_status_reporter_01():
 def test_status_reporter_02(tmp_path):
     """test StatusReporter.load()"""
     # missing reports path
-    st_rpt = StatusReporter.load(str(tmp_path / "status.db"))
+    st_rpt = StatusReporter.load(tmp_path / "status.db")
     assert not st_rpt.reports
     # empty reports and tb paths
-    st_rpt = StatusReporter.load(str(tmp_path / "status.db"), tb_path=str(tmp_path))
+    st_rpt = StatusReporter.load(tmp_path / "status.db", tb_path=tmp_path)
     assert isinstance(st_rpt.reports, list)
     assert not st_rpt.reports
     assert isinstance(st_rpt.tracebacks, list)
@@ -272,26 +275,13 @@ def test_status_reporter_03(mocker, disk, memory, getloadavg):
         assert "MB" not in sysinfo[2][-1]
 
 
-def test_status_reporter_04(tmp_path):
-    """test StatusReporter._scan()"""
-    (tmp_path / "somefile.txt").touch()
-    test_path = tmp_path / "TEST_FILE"
-    test_path.mkdir()
-    assert not any(StatusReporter._scan(str(tmp_path), "TEST_FILE"))
-    test_path.rmdir()
-    test_path.touch()
-    assert not any(StatusReporter._scan(str(tmp_path), "TEST_FILE"))
-    test_path.write_bytes(b"test")
-    assert any(StatusReporter._scan(str(tmp_path), "TEST_FILE"))
-
-
-def test_status_reporter_05(mocker, tmp_path):
+def test_status_reporter_04(mocker, tmp_path):
     """test StatusReporter.summary()"""
     mocker.patch("grizzly.common.status.getpid", side_effect=(1, 2))
     mocker.patch("grizzly.common.status.time", side_effect=count(start=1.0, step=1.0))
-    db_file = str(tmp_path / "status.db")
+    db_file = tmp_path / "status.db"
     # single report
-    status = Status.start(db_file=db_file)
+    status = Status.start(db_file)
     status.ignored = 0
     status.iteration = 1
     status.log_size = 0
@@ -311,7 +301,7 @@ def test_status_reporter_05(mocker, tmp_path):
     assert "Timestamp" not in output
     assert len(output.split("\n")) == 3
     # multiple reports
-    status = Status.start(db_file=db_file)
+    status = Status.start(db_file)
     status.ignored = 1
     status.iteration = 8
     status.log_size = 86900000
@@ -337,12 +327,12 @@ def test_status_reporter_05(mocker, tmp_path):
         assert match(r"\S\s:\s\S", line[position - 2 :])
 
 
-def test_status_reporter_06(mocker, tmp_path):
+def test_status_reporter_05(mocker, tmp_path):
     """test StatusReporter.specific()"""
     mocker.patch("grizzly.common.status.getpid", side_effect=(1, 2))
-    db_file = str(tmp_path / "status.db")
+    db_file = tmp_path / "status.db"
     # single report
-    status = Status.start(db_file=db_file)
+    status = Status.start(db_file)
     status.ignored = 0
     status.iteration = 1
     status.log_size = 0
@@ -357,7 +347,7 @@ def test_status_reporter_06(mocker, tmp_path):
     assert "(Blockers detected)" not in output
     assert "Runtime" in output
     # multiple reports
-    status = Status.start(db_file=db_file, enable_profiling=True)
+    status = Status.start(db_file, enable_profiling=True)
     status.ignored = 1
     status.iteration = 50
     status.results.count("uid1", "sig1")
@@ -382,12 +372,12 @@ def test_status_reporter_06(mocker, tmp_path):
     assert "test2" in output
 
 
-def test_status_reporter_07(mocker, tmp_path):
+def test_status_reporter_06(mocker, tmp_path):
     """test StatusReporter.results()"""
     mocker.patch("grizzly.common.status.getpid", side_effect=(1, 2, 3))
-    db_file = str(tmp_path / "status.db")
+    db_file = tmp_path / "status.db"
     # single report without results
-    status = Status.start(db_file=db_file)
+    status = Status.start(db_file)
     status.ignored = 0
     status.iteration = 1
     status.log_size = 0
@@ -398,13 +388,13 @@ def test_status_reporter_07(mocker, tmp_path):
     assert not rptr.has_results
     assert rptr.results() == "No results available\n"
     # multiple reports with results
-    status = Status.start(db_file=db_file)
+    status = Status.start(db_file)
     status.iteration = 1
     status.results.count("uid1", "[@ test1]")
     status.results.count("uid2", "[@ test2]")
     status.results.count("uid1", "[@ test1]")
     status.report(force=True)
-    status = Status.start(db_file=db_file)
+    status = Status.start(db_file)
     status.iteration = 1
     status.results.count("uid1", "[@ test1]")
     status.results.count("uid3", "[@ longsignature123]")
@@ -420,10 +410,10 @@ def test_status_reporter_07(mocker, tmp_path):
     assert len(output.strip().split("\n")) == 4
 
 
-def test_status_reporter_08(tmp_path):
+def test_status_reporter_07(tmp_path):
     """test StatusReporter.load() with traceback"""
-    db_file = str(tmp_path / "status.db")
-    status = Status.start(db_file=db_file)
+    db_file = tmp_path / "status.db"
+    status = Status.start(db_file)
     status.ignored = 0
     status.iteration = 1
     status.log_size = 0
@@ -435,21 +425,21 @@ def test_status_reporter_08(tmp_path):
         test_fp.write(b"Traceback (most recent call last):\n")
         test_fp.write(b"  blah\n")
         test_fp.write(b"IndexError: list index out of range\n")
-    rptr = StatusReporter.load(db_file, tb_path=str(tmp_path))
+    rptr = StatusReporter.load(db_file, tb_path=tmp_path)
     assert len(rptr.tracebacks) == 1
     # create second screenlog
     with (tmp_path / "screenlog.1234").open("wb") as test_fp:
         test_fp.write(b"Traceback (most recent call last):\n")
         test_fp.write(b"  blah\n")
         test_fp.write(b"foo.bar.error: blah\n")
-    rptr = StatusReporter.load(db_file, tb_path=str(tmp_path))
+    rptr = StatusReporter.load(db_file, tb_path=tmp_path)
     assert len(rptr.tracebacks) == 2
     # create third screenlog
     with (tmp_path / "screenlog.3").open("wb") as test_fp:
         test_fp.write(b"Traceback (most recent call last):\n")
         test_fp.write(b"  blah\n")
         test_fp.write(b"KeyboardInterrupt\n")
-    rptr = StatusReporter.load(db_file, tb_path=str(tmp_path))
+    rptr = StatusReporter.load(db_file, tb_path=tmp_path)
     assert len(rptr.tracebacks) == 2
     merged_log = rptr.summary()
     assert len(merged_log.splitlines()) == 14
@@ -460,14 +450,14 @@ def test_status_reporter_08(tmp_path):
     assert "screenlog.3" not in merged_log
 
 
-def test_status_reporter_09(tmp_path):
+def test_status_reporter_08(tmp_path):
     """test StatusReporter.load() no reports with traceback"""
     # create screenlog with tb
     with (tmp_path / "screenlog.1").open("wb") as test_fp:
         test_fp.write(b"Traceback (most recent call last):\n")
         test_fp.write(b"  blah\n")
         test_fp.write(b"IndexError: list index out of range\n")
-    rptr = StatusReporter.load(str(tmp_path / "status.db"), tb_path=str(tmp_path))
+    rptr = StatusReporter.load(tmp_path / "status.db", tb_path=tmp_path)
     rptr._sys_info = _fake_sys_info
     assert len(rptr.tracebacks) == 1
     output = rptr.summary()
@@ -476,19 +466,19 @@ def test_status_reporter_09(tmp_path):
     assert "IndexError" in output
 
 
-def test_status_reporter_10(mocker, tmp_path):
+def test_status_reporter_09(mocker, tmp_path):
     """test StatusReporter.summary() limit with traceback"""
     mocker.patch("grizzly.common.status.getpid", side_effect=(1, 2))
-    db_file = str(tmp_path / "status.db")
+    db_file = tmp_path / "status.db"
     # create reports
-    status = Status.start(db_file=db_file)
+    status = Status.start(db_file)
     status.ignored = 100
     status.iteration = 1000
     status.log_size = 9999999999
     status.results.count("uid1", "[@ sig1]")
     status.results._count["uid1"] = 123
     status.report(force=True)
-    status = Status.start(db_file=db_file)
+    status = Status.start(db_file)
     status.ignored = 9
     status.iteration = 192938
     status.log_size = 0
@@ -497,15 +487,15 @@ def test_status_reporter_10(mocker, tmp_path):
     status.report(force=True)
     # create screenlogs with tracebacks
     for i in range(10):
-        with (tmp_path / ("screenlog.%d" % (i,))).open("wb") as test_fp:
-            test_fp.write(b"Traceback (most recent call last):\n")
+        with (tmp_path / f"screenlog.{i}").open("w") as test_fp:
+            test_fp.write("Traceback (most recent call last):\n")
             for j in range(TracebackReport.MAX_LINES):
                 test_fp.write(
-                    b'  File "some/long/path/name/foobar.py", line 5000, in <module>\n'
+                    '  File "some/long/path/name/foobar.py", line 5000, in <module>\n'
                 )
-                test_fp.write(b"    some_long_name_for_a_func_%04d()\n" % (j,))
-            test_fp.write(b"IndexError: list index out of range\n")
-    rptr = StatusReporter.load(db_file, tb_path=str(tmp_path))
+                test_fp.write(f"    some_long_name_for_a_func_{j:0>4d}()\n")
+            test_fp.write("IndexError: list index out of range\n")
+    rptr = StatusReporter.load(db_file, tb_path=tmp_path)
     rptr._sys_info = _fake_sys_info
     assert len(rptr.tracebacks) == 10
     merged_log = rptr.summary(
@@ -514,7 +504,7 @@ def test_status_reporter_10(mocker, tmp_path):
     assert len(merged_log) < StatusReporter.SUMMARY_LIMIT
 
 
-def test_status_reporter_11():
+def test_status_reporter_10():
     """test StatusReporter.format_entries()"""
     assert StatusReporter.format_entries([]) == ""
     assert StatusReporter.format_entries([("test", None)]) == "test"
@@ -525,9 +515,11 @@ def test_status_reporter_11():
     assert out == " first : 1\nsecond : 2\n third : 3"
 
 
-def test_traceback_report_01():
+def test_traceback_report_01(tmp_path):
     """test simple TracebackReport"""
-    tbr = TracebackReport("log.txt", ["0", "1", "2"], prev_lines=["-2", "-1"])
+    tbr = TracebackReport(
+        tmp_path / "log.txt", ["0", "1", "2"], prev_lines=["-2", "-1"]
+    )
     output = str(tbr)
     assert len(output.splitlines()) == 6
     assert len(tbr) == 26
@@ -536,9 +528,9 @@ def test_traceback_report_01():
     assert "-2" in output
 
 
-def test_traceback_report_02():
+def test_traceback_report_02(tmp_path):
     """test empty TracebackReport"""
-    tbr = TracebackReport("log.txt", [])
+    tbr = TracebackReport(tmp_path / "log.txt", [])
     assert not tbr.is_kbi
     output = str(tbr)
     assert len(output.splitlines()) == 1
@@ -548,16 +540,16 @@ def test_traceback_report_02():
 def test_traceback_report_03(tmp_path):
     """test TracebackReport.from_file()"""
     test_log = tmp_path / "screenlog.0"
-    with test_log.open("wb") as test_fp:
-        test_fp.write(b"start junk\npre1\npre2\npre3\npre4\npre5\n")
-        test_fp.write(b"Traceback (most recent call last):\n")
-        test_fp.write(b'  File "foo.py", line 556, in <module>\n')
-        test_fp.write(b"    main(parse_args())\n")
-        test_fp.write(b'  File "foo.py", line 207, in bar\n')
-        test_fp.write(b"    a = b[10]\n")
-        test_fp.write(b"IndexError: list index out of range\n")
-        test_fp.write(b"end junk\n")
-    tbr = TracebackReport.from_file(str(test_log))
+    with test_log.open("w") as test_fp:
+        test_fp.write("start junk\npre1\npre2\npre3\npre4\npre5\n")
+        test_fp.write("Traceback (most recent call last):\n")
+        test_fp.write('  File "foo.py", line 556, in <module>\n')
+        test_fp.write("    main(parse_args())\n")
+        test_fp.write('  File "foo.py", line 207, in bar\n')
+        test_fp.write("    a = b[10]\n")
+        test_fp.write("IndexError: list index out of range\n")
+        test_fp.write("end junk\n")
+    tbr = TracebackReport.from_file(test_log, ignore_kbi=True)
     assert len(tbr.prev_lines) == 5
     assert len(tbr.lines) == 6
     assert not tbr.is_kbi
@@ -568,16 +560,16 @@ def test_traceback_report_03(tmp_path):
     assert "screenlog.0" in output
     assert "junk" not in output
 
-    with test_log.open("wb") as test_fp:
-        test_fp.write(b"start junk\n")
-        test_fp.write(b"Traceback (most recent call last):\n")
-        test_fp.write(b'  File "foo.py", line 556, in <module>\n')
-        test_fp.write(b"    main(parse_args())\n")
-        test_fp.write(b'  File "foo.py", line 207, in bar\n')
-        test_fp.write(b"    a = b[10]\n")
-        test_fp.write(b"foo.bar.error: blah\n")
-        test_fp.write(b"end junk\n")
-    tbr = TracebackReport.from_file(str(test_log), max_preceding=0)
+    with test_log.open("w") as test_fp:
+        test_fp.write("start junk\n")
+        test_fp.write("Traceback (most recent call last):\n")
+        test_fp.write('  File "foo.py", line 556, in <module>\n')
+        test_fp.write("    main(parse_args())\n")
+        test_fp.write('  File "foo.py", line 207, in bar\n')
+        test_fp.write("    a = b[10]\n")
+        test_fp.write("foo.bar.error: blah\n")
+        test_fp.write("end junk\n")
+    tbr = TracebackReport.from_file(test_log, max_preceding=0)
     assert len(tbr.lines) == 6
     assert not tbr.prev_lines
     assert not tbr.is_kbi
@@ -587,36 +579,38 @@ def test_traceback_report_03(tmp_path):
     assert "foo.bar.error" in output
     assert "junk" not in output
     # kbi
-    with test_log.open("wb") as test_fp:
-        test_fp.write(b"Traceback (most recent call last):\n")
-        test_fp.write(b'  File "foo.py", line 556, in <module>\n')
-        test_fp.write(b"    main(parse_args())\n")
-        test_fp.write(b'  File "foo.py", line 207, in bar\n')
-        test_fp.write(b"    a = b[10]\n")
-        test_fp.write(b"KeyboardInterrupt\n")
-        test_fp.write(b"end junk\n")
-    tbr = TracebackReport.from_file(str(test_log))
+    with test_log.open("w") as test_fp:
+        test_fp.write("Traceback (most recent call last):\n")
+        test_fp.write('  File "foo.py", line 556, in <module>\n')
+        test_fp.write("    main(parse_args())\n")
+        test_fp.write('  File "foo.py", line 207, in bar\n')
+        test_fp.write("    a = b[10]\n")
+        test_fp.write("KeyboardInterrupt\n")
+        test_fp.write("end junk\n")
+    tbr = TracebackReport.from_file(test_log)
     assert tbr.is_kbi
     output = str(tbr)
     assert len(output.splitlines()) == 7
     assert "KeyboardInterrupt" in output
+    # ignore kbi
+    assert TracebackReport.from_file(test_log, ignore_kbi=True) is None
 
 
 def test_traceback_report_04(tmp_path):
     """test TracebackReport.from_file() exceed size limit"""
     test_log = tmp_path / "screenlog.0"
-    with test_log.open("wb") as test_fp:
-        test_fp.write(b"Traceback (most recent call last):\n")
-        test_fp.write(b'  File "foo.py", line 5, in <module>\n')
-        test_fp.write(b"    first()\n")
-        test_fp.write(b'  File "foo.py", line 5, in <module>\n')
-        test_fp.write(b"    second()\n")
+    with test_log.open("w") as test_fp:
+        test_fp.write("Traceback (most recent call last):\n")
+        test_fp.write('  File "foo.py", line 5, in <module>\n')
+        test_fp.write("    first()\n")
+        test_fp.write('  File "foo.py", line 5, in <module>\n')
+        test_fp.write("    second()\n")
         for i in reversed(range(TracebackReport.MAX_LINES)):
-            test_fp.write(b'  File "foo.py", line 5, in <module>\n')
-            test_fp.write(b"    func_%02d()\n" % i)
-        test_fp.write(b"END_WITH_BLANK_LINE\n\n")
-        test_fp.write(b"end junk\n")
-    tbr = TracebackReport.from_file(str(test_log))
+            test_fp.write('  File "foo.py", line 5, in <module>\n')
+            test_fp.write(f"    func_{i:0>2d}()\n")
+        test_fp.write("END_WITH_BLANK_LINE\n\n")
+        test_fp.write("end junk\n")
+    tbr = TracebackReport.from_file(test_log)
     assert not tbr.is_kbi
     output = str(tbr)
     assert len(output.splitlines()) == 18
@@ -631,31 +625,31 @@ def test_traceback_report_04(tmp_path):
 def test_traceback_report_05(tmp_path):
     """test TracebackReport.from_file() cut off"""
     test_log = tmp_path / "screenlog.0"
-    with test_log.open("wb") as test_fp:
-        test_fp.write(b"Traceback (most recent call last):\n")
-        test_fp.write(b'  File "foo.py", line 5, in <module>\n')
-        test_fp.write(b"    first()\n")
+    with test_log.open("w") as test_fp:
+        test_fp.write("Traceback (most recent call last):\n")
+        test_fp.write('  File "foo.py", line 5, in <module>\n')
+        test_fp.write("    first()\n")
         for i in range(TracebackReport.MAX_LINES * 2):
-            test_fp.write(b'  File "foo.py", line 5, in <module>\n')
-            test_fp.write(b"    func_%d()\n" % i)
-    tbr = TracebackReport.from_file(str(test_log))
+            test_fp.write('  File "foo.py", line 5, in <module>\n')
+            test_fp.write(f"    func_{i}()\n")
+    tbr = TracebackReport.from_file(test_log)
     assert not tbr.is_kbi
     output = str(tbr)
     assert len(output.splitlines()) == 18
     assert "first()" in output
-    assert "func_%d" % (TracebackReport.MAX_LINES * 2 - 1) in output
+    assert f"func_{TracebackReport.MAX_LINES * 2 - 1}" in output
 
 
 def test_traceback_report_06(tmp_path):
     """test TracebackReport.from_file() single word error"""
     test_log = tmp_path / "screenlog.0"
-    with test_log.open("wb") as test_fp:
-        test_fp.write(b"Traceback (most recent call last):\n")
-        test_fp.write(b'  File "foo.py", line 5, in <module>\n')
-        test_fp.write(b"    first()\n")
-        test_fp.write(b"AssertionError\n")
-        test_fp.write(b"end junk\n")
-    tbr = TracebackReport.from_file(str(test_log))
+    with test_log.open("w") as test_fp:
+        test_fp.write("Traceback (most recent call last):\n")
+        test_fp.write('  File "foo.py", line 5, in <module>\n')
+        test_fp.write("    first()\n")
+        test_fp.write("AssertionError\n")
+        test_fp.write("end junk\n")
+    tbr = TracebackReport.from_file(test_log)
     assert not tbr.is_kbi
     output = str(tbr)
     assert len(output.splitlines()) == 5
@@ -672,7 +666,7 @@ def test_traceback_report_07(tmp_path):
         test_fp.write(b'  File "foo.py", line 5, in <module>\n')
         test_fp.write(b"    bin\xd8()\n")
         test_fp.write(b"AssertionError\n")
-    tbr = TracebackReport.from_file(str(test_log))
+    tbr = TracebackReport.from_file(test_log)
     assert not tbr.is_kbi
     output = str(tbr)
     assert "bin()" in output
@@ -682,13 +676,13 @@ def test_traceback_report_07(tmp_path):
 def test_traceback_report_08(tmp_path):
     """test TracebackReport.from_file() locate token across chunks"""
     test_log = tmp_path / "screenlog.0"
-    with test_log.open("wb") as test_fp:
-        test_fp.write(b"A" * (TracebackReport.READ_LIMIT - 5))
-        test_fp.write(b"Traceback (most recent call last):\n")
-        test_fp.write(b'  File "foo.py", line 5, in <module>\n')
-        test_fp.write(b"    first()\n")
-        test_fp.write(b"AssertionError\n")
-    tbr = TracebackReport.from_file(str(test_log))
+    with test_log.open("w") as test_fp:
+        test_fp.write("A" * (TracebackReport.READ_LIMIT - 5))
+        test_fp.write("Traceback (most recent call last):\n")
+        test_fp.write('  File "foo.py", line 5, in <module>\n')
+        test_fp.write("    first()\n")
+        test_fp.write("AssertionError\n")
+    tbr = TracebackReport.from_file(test_log)
     assert not tbr.is_kbi
     output = str(tbr)
     assert len(output.splitlines()) == 5
@@ -696,28 +690,27 @@ def test_traceback_report_08(tmp_path):
     assert "AssertionError" in output
 
 
-@mark.usefixtures("tmp_path_status_db")
-def test_main_01(mocker):
-    """test main() with no reports"""
-    mocker.patch(
-        "grizzly.common.status_reporter.StatusReporter.CPU_POLL_INTERVAL", 0.01
-    )
+def test_main_01(mocker, tmp_path):
+    """test main()"""
+    status_db = tmp_path / "status.db"
+    mocker.patch("grizzly.common.status_reporter.STATUS_DB_FUZZ", status_db)
+    # without a report
     assert main([]) == 0
-
-
-@mark.usefixtures("tmp_path_status_db")
-def test_main_02(mocker):
-    """test main() with a report"""
-    mocker.patch(
-        "grizzly.common.status_reporter.StatusReporter.CPU_POLL_INTERVAL", 0.01
-    )
-    status = Status.start()
+    # with a report
+    status = Status.start(status_db)
     status.iteration = 1
     status.results.count("uid", "[@ test]")
     status.report(force=True)
     assert main([]) == 0
 
 
+def test_main_02(capsys):
+    """test main() with invalid args"""
+    with raises(SystemExit):
+        main(["--tracebacks", "missing"])
+    assert "--tracebacks must be a directory" in capsys.readouterr()[-1]
+
+
 @mark.parametrize(
     "report_mode",
     [
@@ -732,14 +725,14 @@ def test_main_02(mocker):
         "complete",
     ],
 )
-@mark.usefixtures("tmp_path_status_db", "tmp_path_reduce_status_db")
 def test_main_03(mocker, tmp_path, report_type, report_mode):
     """test main() --dump"""
-    mocker.patch(
-        "grizzly.common.status_reporter.StatusReporter.CPU_POLL_INTERVAL", 0.01
-    )
+    mocker.patch("grizzly.common.status_reporter.cpu_percent", return_value=10)
+    status_db = tmp_path / "status.db"
     if report_mode == "reducing":
+        mocker.patch("grizzly.common.status_reporter.STATUS_DB_REDUCE", status_db)
         status = ReductionStatus.start(
+            status_db,
             testcase_size_cb=lambda: 47,
             strategies=[],
         )
@@ -747,7 +740,8 @@ def test_main_03(mocker, tmp_path, report_type, report_mode):
             status.iteration = 1
         status.report(force=True)
     else:
-        status = Status.start()
+        mocker.patch("grizzly.common.status_reporter.STATUS_DB_FUZZ", status_db)
+        status = Status.start(status_db)
         status.iteration = 1
         status.report(force=True)
     dump_file = tmp_path / "output.txt"
@@ -771,14 +765,6 @@ def test_main_03(mocker, tmp_path, report_type, report_mode):
         assert b"Timestamp" not in dump_file.read_bytes()
 
 
-@mark.usefixtures("tmp_path_status_db")
-def test_main_04(capsys):
-    """test main() with invalid args"""
-    with raises(SystemExit):
-        main(["--tracebacks", "missing"])
-    assert "--tracebacks must be a directory" in capsys.readouterr()[-1]
-
-
 @mark.parametrize(
     "report_type",
     [
@@ -786,13 +772,13 @@ def test_main_04(capsys):
         "complete",
     ],
 )
-@mark.usefixtures("tmp_path_reduce_status_db")
-def test_main_05(mocker, tmp_path, report_type):
+def test_main_04(mocker, tmp_path, report_type):
     """test main() --dump"""
-    mocker.patch(
-        "grizzly.common.status_reporter.StatusReporter.CPU_POLL_INTERVAL", 0.01
-    )
+    mocker.patch("grizzly.common.status_reporter.cpu_percent", return_value=10)
+    status_db = tmp_path / "status.db"
+    mocker.patch("grizzly.common.status_reporter.STATUS_DB_REDUCE", status_db)
     status = ReductionStatus.start(
+        status_db,
         testcase_size_cb=lambda: 47,
         strategies=[],
     )
