@@ -1,4 +1,3 @@
-# coding=utf-8
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
@@ -301,7 +300,7 @@ def test_testcase_11(tmp_path):
     """test TestCase.load() - missing file and empty directory"""
     # missing file
     with raises(TestCaseLoadFailure, match="Invalid TestCase path"):
-        TestCase.load("missing")
+        TestCase.load(tmp_path / "missing")
     # empty path
     assert not TestCase.load(tmp_path, adjacent=True)
 
@@ -433,7 +432,7 @@ def test_testcase_17(tmp_path):
     (tmp_path / "not-test").mkdir()
     assert not any(TestCase.scan_path(tmp_path))
     # multiple test case directories
-    paths = [tmp_path / ("test-%d" % i) for i in range(3)]
+    paths = [tmp_path / f"test-{i}" for i in range(3)]
     with TestCase("test.htm", None, "test-adapter") as src:
         src.add_from_bytes(b"test", "test.htm")
         for path in paths:
