@@ -137,7 +137,7 @@ class ReduceManager:
         self._original_use_harness = use_harness
         self._report_to_fuzzmanager = report_to_fuzzmanager
         self._report_periodically = report_period
-        self._report_tool = tool
+        self._report_tool = tool or "grizzly-reducer"
         self._signature = signature
         self._signature_desc = signature_desc
         self._static_timeout = expect_hang or static_timeout
@@ -428,7 +428,7 @@ class ReduceManager:
         """
         return sum(tc.data_size for tc in self.testcases)
 
-    def run(self, repeat=1, launch_attempts=3, min_results=1):
+    def run(self, repeat=1, launch_attempts=3, min_results=1, post_launch_delay=0):
         """Run testcase reduction.
 
         Args:
@@ -436,6 +436,8 @@ class ReduceManager:
             launch_attempts (int): Number of attempts to launch the browser.
             min_results (int): Minimum number of results needed before run can
                                be considered successful.
+            post_launch_delay (int): Time in seconds before continuing after the
+                                     browser is launched.
 
         Returns:
             int: One of the Exit enum values.
@@ -514,6 +516,7 @@ class ReduceManager:
                                     min_results=min_results,
                                     repeat=repeat,
                                     on_iteration_cb=self._on_replay_iteration,
+                                    post_launch_delay=post_launch_delay,
                                 )
                                 self._status.attempts += 1
                                 self.update_timeout(results)
@@ -530,10 +533,9 @@ class ReduceManager:
                                         not self._any_crash
                                         and self._signature_desc is None
                                     ):
-                                        self._signature_desc = (
-                                            # pylint: disable=line-too-long
-                                            first_expected.report.crash_info.createShortSignature()  # noqa: E501
-                                        )
+                                        crash = first_expected.report.crash_info
+                                        sig = crash.createShortSignature()
+                                        self._signature_desc = sig
                                 self._status.report()
                                 served = None
                                 if success and not self._any_crash:
@@ -799,12 +801,9 @@ class ReduceManager:
                 LOG.error("Error: %s", str(exc))
                 return Exit.ERROR
 
-            if args.tool is None and testcases[0].adapter_name is not None:
-                LOG.warning(
-                    "Setting default --tool=grizzly-%s from testcase",
-                    testcases[0].adapter_name,
-                )
+            if not args.tool and testcases[0].adapter_name:
                 args.tool = f"grizzly-{testcases[0].adapter_name}"
+                LOG.warning("Setting default --tool=%s from testcase", args.tool)
 
             expect_hang = ReplayManager.expect_hang(args.ignore, signature, testcases)
 
@@ -873,6 +872,7 @@ class ReduceManager:
                     repeat=args.repeat,
                     launch_attempts=args.launch_attempts,
                     min_results=args.min_crashes,
+                    post_launch_delay=args.post_launch_delay,
                 )
             return return_code
 
