@@ -1,4 +1,3 @@
-# coding=utf-8
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
@@ -26,8 +25,7 @@ LOG = getLogger(__name__)
 pytestmark = mark.usefixtures(
     "reporter_sequential_strftime",
     "tmp_path_fm_config",
-    "tmp_path_replay_status_db",
-    "tmp_path_reduce_status_db",
+    "tmp_path_status_db_reduce",
 )
 
 
@@ -266,10 +264,10 @@ def test_analysis(
             kw["on_iteration_cb"]()
             LOG.debug("interesting: %r", crashes[0])
             if crashes.pop(0):
-                log_path = tmp_path / ("crash%d_logs" % (replayer.run.call_count,))
+                log_path = tmp_path / f"crash{replayer.run.call_count}_logs"
                 log_path.mkdir(exist_ok=True)
                 _fake_save_logs_foo(log_path)
-                report = Report(str(log_path), "bin")
+                report = Report(log_path, "bin")
                 results.append(ReplayResult(report, [["test.html"]], [], True))
         return results
 
@@ -515,14 +513,14 @@ def test_repro(
             # pylint: disable=logging-not-lazy
             LOG.debug("interesting if " + interesting_str, contents)
             if detect_failure(contents):
-                log_path = tmp_path / ("crash%d_logs" % (replayer.run.call_count,))
+                log_path = tmp_path / f"crash{replayer.run.call_count}_logs"
                 log_path.mkdir()
                 expected = is_expected(contents)
                 if expected:
                     _fake_save_logs_foo(log_path)
                 else:
                     _fake_save_logs_bar(log_path)
-                report = Report(str(log_path), "bin")
+                report = Report(log_path, "bin")
                 return [ReplayResult(report, [["test.html"]], [], expected)]
         return []
 
@@ -534,7 +532,7 @@ def test_repro(
     log_path = tmp_path / "logs"
 
     target = mocker.Mock(spec_set=Target)
-    target.filtered_environ.return_value = dict()
+    target.filtered_environ.return_value = {}
     target.assets = mocker.Mock(spec_set=AssetManager)
     try:
         mgr = ReduceManager(
@@ -589,17 +587,17 @@ def test_report_01(mocker, tmp_path):
     def replay_run(_tests, _time_limit, **kw):
         kw["on_iteration_cb"]()
         if replayer.run.call_count in {20, 40}:
-            log_path = tmp_path / ("crash%d_logs" % (replayer.run.call_count,))
+            log_path = tmp_path / f"crash{replayer.run.call_count}_logs"
             log_path.mkdir()
             _fake_save_logs_foo(log_path)
-            report = Report(str(log_path), "bin")
+            report = Report(log_path, "bin")
             return [ReplayResult(report, [["test.html"]], [], True)]
         return []
 
     replayer.run.side_effect = replay_run
 
     (tmp_path / "test.html").touch()
-    testcases = TestCase.load(str(tmp_path / "test.html"))
+    testcases = TestCase.load(tmp_path / "test.html")
     assert testcases
     log_path = tmp_path / "logs"
 
@@ -610,7 +608,7 @@ def test_report_01(mocker, tmp_path):
         for count_ in range(1, 61):
             LOG.debug("fake_iter() %d", count_)
             (tmp_path / "test.html").write_text(str(count_))
-            testcases = TestCase.load(str(tmp_path / "test.html"))
+            testcases = TestCase.load(tmp_path / "test.html")
             assert testcases
             yield testcases
 
@@ -618,7 +616,7 @@ def test_report_01(mocker, tmp_path):
     mocker.patch("grizzly.reduce.core.STRATEGIES", new={"fake": fake_strat})
 
     target = mocker.Mock(spec_set=Target)
-    target.filtered_environ.return_value = dict()
+    target.filtered_environ.return_value = {}
     target.assets = mocker.Mock(spec_set=AssetManager)
     try:
         mgr = ReduceManager(
@@ -660,17 +658,17 @@ def test_report_02(mocker, tmp_path):
     def replay_run(_tests, _time_limit, **kw):
         kw["on_iteration_cb"]()
         if replayer.run.call_count in {10, 20}:
-            log_path = tmp_path / ("crash%d_logs" % (replayer.run.call_count,))
+            log_path = tmp_path / f"crash{replayer.run.call_count}_logs"
             log_path.mkdir()
             _fake_save_logs_foo(log_path)
-            report = Report(str(log_path), "bin")
+            report = Report(log_path, "bin")
             return [ReplayResult(report, [["test.html"]], [], True)]
         return []
 
     replayer.run.side_effect = replay_run
 
     (tmp_path / "test.html").touch()
-    testcases = TestCase.load(str(tmp_path / "test.html"))
+    testcases = TestCase.load(tmp_path / "test.html")
     assert testcases
     log_path = tmp_path / "logs"
 
@@ -681,7 +679,7 @@ def test_report_02(mocker, tmp_path):
         for count_ in range(1, 31):
             LOG.debug("fake_iter() %d", count_)
             (tmp_path / "test.html").write_text(str(count_))
-            testcases = TestCase.load(str(tmp_path / "test.html"))
+            testcases = TestCase.load(tmp_path / "test.html")
             assert testcases
             yield testcases
         raise KeyboardInterrupt()
@@ -690,7 +688,7 @@ def test_report_02(mocker, tmp_path):
     mocker.patch("grizzly.reduce.core.STRATEGIES", new={"fake": fake_strat})
 
     target = mocker.Mock(spec_set=Target)
-    target.filtered_environ.return_value = dict()
+    target.filtered_environ.return_value = {}
     target.assets = mocker.Mock(spec_set=AssetManager)
     try:
         mgr = ReduceManager(
@@ -732,17 +730,17 @@ def test_quality_update(mocker, tmp_path):
             contents = test.get_file("test.html").data_file.read_text()
             if not contents.strip():
                 continue
-            log_path = tmp_path / ("crash%d_logs" % (replayer.run.call_count,))
+            log_path = tmp_path / f"crash{replayer.run.call_count}_logs"
             log_path.mkdir()
             _fake_save_logs_foo(log_path)
-            report = Report(str(log_path), "bin")
+            report = Report(log_path, "bin")
             return [ReplayResult(report, [["test.html"]], [], True)]
         return []
 
     replayer.run.side_effect = replay_run
 
     (tmp_path / "test.html").write_text("123\n")
-    testcases = TestCase.load(str(tmp_path / "test.html"))
+    testcases = TestCase.load(tmp_path / "test.html")
     assert testcases
     log_path = tmp_path / "logs"
 
@@ -751,7 +749,7 @@ def test_quality_update(mocker, tmp_path):
     reporter.return_value.submit.return_value = 1234
     update_coll = mocker.patch("grizzly.common.fuzzmanager.Collector")
     target = mocker.Mock(spec_set=Target)
-    target.filtered_environ.return_value = dict()
+    target.filtered_environ.return_value = {}
     target.assets = mocker.Mock(spec_set=AssetManager)
     try:
         mgr = ReduceManager(
@@ -795,17 +793,17 @@ def test_include_assets_and_environ(mocker, tmp_path):
             contents = test.get_file("test.html").data_file.read_text()
             if not contents.strip():
                 continue
-            log_path = tmp_path / ("crash%d_logs" % (replayer.run.call_count,))
+            log_path = tmp_path / f"crash{replayer.run.call_count}_logs"
             log_path.mkdir()
             _fake_save_logs_foo(log_path)
-            report = Report(str(log_path), "bin")
+            report = Report(log_path, "bin")
             return [ReplayResult(report, [["test.html"]], [], True)]
         return []
 
     replayer.run.side_effect = replay_run
 
     (tmp_path / "test.html").write_text("123\n")
-    testcases = TestCase.load(str(tmp_path / "test.html"))
+    testcases = TestCase.load(tmp_path / "test.html")
     assert testcases
     log_path = tmp_path / "logs"
 
@@ -932,10 +930,10 @@ def test_timeout_update(
     def replay_run(_testcases, _time_limit, **kw):
         kw["on_iteration_cb"]()
         LOG.debug("interesting true")
-        log_path = tmp_path / ("crash%d_logs" % (replayer.run.call_count,))
+        log_path = tmp_path / f"crash{replayer.run.call_count}_logs"
         log_path.mkdir()
         _fake_save_logs_foo(log_path)
-        report = Report(str(log_path), "bin")
+        report = Report(log_path, "bin")
         return [ReplayResult(report, [["test.html"]], durations, interesting)]
 
     replayer.run.side_effect = replay_run
@@ -946,7 +944,7 @@ def test_timeout_update(
     log_path = tmp_path / "logs"
 
     target = mocker.Mock(spec_set=Target)
-    target.filtered_environ.return_value = dict()
+    target.filtered_environ.return_value = {}
     target.assets = mocker.Mock(spec_set=AssetManager)
     server = mocker.Mock(spec_set=Sapphire, timeout=iter_input)
     try:
