@@ -8,6 +8,17 @@ from pathlib import Path
 
 from pytest import fixture
 
+from sapphire import Sapphire
+
+
+@fixture
+def server(mocker):
+    """Mock Sapphire server"""
+    srv = mocker.Mock(spec_set=Sapphire, port=1337, timeout=10)
+    srv_cls = mocker.patch("grizzly.replay.replay.Sapphire", autospec=True)
+    srv_cls.return_value.__enter__.return_value = srv
+    return srv
+
 
 @fixture
 def tmp_path_grz_tmp(tmp_path, mocker):
@@ -16,6 +27,6 @@ def tmp_path_grz_tmp(tmp_path, mocker):
     def _grz_tmp(*subdir):
         path = Path(tmp_path, "grizzly", *subdir)
         path.mkdir(parents=True, exist_ok=True)
-        return str(path)
+        return path
 
     mocker.patch("grizzly.replay.replay.grz_tmp", _grz_tmp)
