@@ -20,7 +20,14 @@ from ..common.reporter import (
 from ..common.runner import Runner
 from ..common.status import SimpleStatus
 from ..common.storage import TestCase, TestCaseLoadFailure
-from ..common.utils import ConfigError, Exit, configure_logging, grz_tmp, time_limits
+from ..common.utils import (
+    ConfigError,
+    Exit,
+    configure_logging,
+    display_time_limits,
+    grz_tmp,
+    time_limits,
+)
 from ..target import Result, Target, TargetLaunchError, TargetLaunchTimeout
 
 __author__ = "Tyson Smith"
@@ -223,8 +230,8 @@ class ReplayManager:
         Returns:
             None
         """
-        if tests and not tool:
-            tool = tests[0].adapter_name
+        if not tool and tests and tests[0].adapter_name:
+            tool = f"grizzly-{tests[0].adapter_name}"
         reporter = FuzzManagerReporter(tool or "grizzly-replay")
         for result in results:
             # always report expected results
@@ -244,7 +251,7 @@ class ReplayManager:
         idle_threshold=0,
         launch_attempts=3,
         on_iteration_cb=None,
-        post_launch_delay=None,
+        post_launch_delay=0,
     ):
         """Run testcase replay.
 
@@ -264,8 +271,8 @@ class ReplayManager:
             idle_threshold (int): CPU usage threshold to mark the process as idle.
             launch_attempts (int): Number of attempts to launch the browser.
             on_iteration_cb (callable): Called every time a single iteration is run.
-            post_launch_delay (int): Time in seconds before test case is loaded after
-                                     the browser is launched.
+            post_launch_delay (int): Time in seconds before continuing after the
+                                     browser is launched.
 
         Returns:
             list: ReplayResults that were found running testcases.
@@ -321,6 +328,7 @@ class ReplayManager:
                     )
                     runner.launch(location, max_retries=launch_attempts)
                     runner.post_launch(delay=post_launch_delay)
+                    # TODO: avoid running test case if runner.startup_failure is True
                 # run tests
                 durations = []
                 served = []
@@ -593,10 +601,7 @@ class ReplayManager:
             time_limit, timeout = time_limits(
                 args.time_limit, args.timeout, tests=testcases
             )
-            if args.no_harness:
-                LOG.info("Using timeout: %ds (no harness)", timeout)
-            else:
-                LOG.info("Using time limit: %ds, timeout: %ds", time_limit, timeout)
+            display_time_limits(time_limit, timeout, args.no_harness)
             # calculate repeat and relaunch
             repeat = max(args.min_crashes, args.repeat)
             relaunch = min(args.relaunch, repeat)
