@@ -108,7 +108,7 @@ class PuppetTarget(Target):
         self._puppet = FFPuppet(
             debugger=debugger,
             headless=kwds.pop("headless", None),
-            working_path=grz_tmp("target"),
+            working_path=str(grz_tmp("target")),
         )
         if kwds:
             LOG.warning(
@@ -397,7 +397,7 @@ class PuppetTarget(Target):
                 else:
                     LOG.warning("Missing %s suppressions file %r", sanitizer, supp_file)
             else:
-                # nothing to do
+                LOG.debug("%r does not contain suppressions", var_name)
                 continue
             # update sanitized *SAN_OPTIONS
             LOG.debug("updating suppressions in %r", var_name)
